@@ -15,6 +15,11 @@ MAX_MESSAGES_PER_BATCH = 500
 
 
 class Device(models.Model):
+    id = models.AutoField(
+        verbose_name="ID",
+        primary_key=True,
+        auto_created=True,
+    )
     name = models.CharField(
         max_length=255, verbose_name=_("Name"), blank=True, null=True
     )
@@ -24,7 +29,11 @@ class Device(models.Model):
         help_text=_("Inactive devices will not be sent notifications"),
     )
     user = models.ForeignKey(
-        SETTINGS["USER_MODEL"], blank=True, null=True, on_delete=models.CASCADE
+        SETTINGS["USER_MODEL"],
+        blank=True,
+        null=True,
+        on_delete=models.CASCADE,
+        related_query_name=_("fcmdevice"),
     )
     date_created = models.DateTimeField(
         verbose_name=_("Creation date"), auto_now_add=True, null=True
@@ -344,6 +353,21 @@ class AbstractFCMDevice(Device):
             [registration_id], [messaging.SendResponse({"name": name}, firebase_exc)]
         )
 
+    @staticmethod
+    def send_topic_message(
+        message: messaging.Message,
+        topic_name: str,
+        **more_send_message_kwargs,
+    ) -> Union[Optional[messaging.SendResponse], FirebaseError]:
+        message.topic = topic_name
+
+        try:
+            return messaging.SendResponse(
+                {"name": messaging.send(message, **more_send_message_kwargs)}, None
+            )
+        except FirebaseError as e:
+            return e
+
 
 class FCMDevice(AbstractFCMDevice):
     class Meta:
